#
# spec file for package fflas-ffpack
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without openblas

Name:           fflas-ffpack
%define lname	libfflas0
Version:        2.5.0
Release:        1.13
Summary:        Finite Field Linear Algebra Subroutines
License:        LGPL-2.1-or-later
Group:          Productivity/Scientific/Math
URL:            https://linbox-team.github.io/fflas-ffpack/

#Git-Clone:	https://github.com/linbox-team/fflas-ffpack
Source:         https://github.com/linbox-team/fflas-ffpack/releases/download/v%version/fflas-ffpack-%version.tar.gz
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  gmp-devel >= 3.1.1
BuildRequires:  libtool >= 2.2
%if %{with openblas}
BuildRequires:  openblas-devel
%else
BuildRequires:  blas-devel
BuildRequires:  cblas-devel
%endif
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(givaro) >= 4.1.2

%description
The FFLAS-FFPACK library provides functionalities for dense linear
algebra over word size prime finite field.

%package devel
Summary:        Development files for FFLAS-FFPACK
Group:          Development/Libraries/C and C++

%description devel
The FFLAS-FFPACK library provides functionalities for dense linear
algebra over word size prime finite field.

This subpackage contains the include files for
developing against the fflas-ffpack library.

%package doc
Summary:        API documentation for FFLAS-FFPACK
Group:          Documentation/HTML
BuildArch:      noarch

%description doc
The FFLAS-FFPACK library provides functionalities for dense linear
algebra over word size prime finite field.

This subpackage contains the Doxygen-generated HTML documentation for
the FFLAS-FFPACK API.

%prep
%autosetup -p1

#Do not compile in DATE and TIME
sed '/HTML_TIMESTAMP/s/YES/NO/' -i doc/Doxyfile

%build
# tarball strangely created; wants to rerun aclocal-1.15.
autoreconf -fi

trap "cat config.log; exit 1" ERR
%configure \
	--with-blas-cflags=" " \
%if %{with openblas}
	--with-blas-libs="-lopenblas" \
%else
	--with-blas-libs="-lcblas -lblas" \
%endif
	--enable-doc --with-docdir="%_docdir/%name" \
	--disable-simd --without-archnative
trap "" ERR
%make_build

%install
%make_install
rm -f "%buildroot/%_docdir/%name/fflas-ffpack-html/INSTALL"
perl -i -lpe 's{^#!/usr/bin/env bash$}{#!/bin/bash}g' %buildroot/%_bindir/*-config
%fdupes %buildroot/%_prefix

%files devel
%doc ChangeLog
%license COPYING.LESSER
%_bindir/fflas-ffpack-config
%_includedir/fflas-ffpack/
%_libdir/pkgconfig/ff*.pc

%files doc
%_docdir/%name/

%changelog
* Tue Dec 14 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.5.0
  * First support for quasiseparable matrices (Compact Bruhat generators)
  * Sub-cubic fsyrk (C <- a. A x A^T + b C)
- Drop reproducible.patch (merged)
* Sat Aug 24 2019 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 2.4.3
  * New features:
  * fsytrf: a symmetric triangular factorization
  * fsyrk, fsyr2k, ftrssyr2k, ftrstr:
    subroutines for symmetric operations.
  * parallelization of fgemm-rns, fsytrf, echelon forms,
    det, rank, etc.
  * API for parallel routines outside of par-block
    (for e.g. SageMath)
* Fri Jul 13 2018 bwiedemann@suse.com
- Add reproducible.patch to disable compile-time CPU detection (boo#1100677)
* Tue Jun 19 2018 schwab@suse.de
- Add option to build without openblas
- Use %%license for COPYING.LESSER
* Mon Dec 25 2017 jengelh@inai.de
- Update to new upstream release 2.3.2
  * new specialization for fgemv over recint
  * improved fttrtri (triangular matrix inverse)
  * clean-up and update all random matrix generator so they can
    be seeded.
  * new pfgemv routine (parallel matrix vector product)
  * new fpotrf routine (Cholesky factorization) and symmetric
    rand generator
  * Gauss-Jordan inverse made to work
  * change signature for CharPoly (now takes a polynomial domain
    as input)
  * change the signature of ftrtrm
* Sat Sep  9 2017 jengelh@inai.de
- For the BLAS implementation, switch from cblas to openblas.
* Tue Nov 29 2016 jengelh@inai.de
- Add --disable-simd to fix spurious failures
* Mon Nov 28 2016 jengelh@inai.de
- From time to time, configure fails to find lapack when built in
  openSUSE:Factory. Emit config.log when that happens.
* Thu Oct 20 2016 jengelh@inai.de
- Update to new upstream release 2.2.2
  * new feature: checkers for Freivalds based verification
  * improved performance of permutation application
* Fri Jun 17 2016 jengelh@inai.de
- Drop gone libatlas3-devel
* Wed Jun  8 2016 jengelh@inai.de
- Update to new upstream release 2.2.1
  * fixes all remaining issues for the integration in SageMath
  * numerous minor fixes to the parallel code
* Mon May 30 2016 jengelh@inai.de
- Switch from ATLAS to CBLAS
* Sat Mar 12 2016 jengelh@inai.de
- Update to new upstream release 2.2.0
  * improvements and API change for the parallel code
  * new random matrix generators
* Tue Jan 19 2016 jengelh@inai.de
- New homepage and SCM URLs
* Sat Nov 14 2015 jengelh@inai.de
- Update to new upstream release 2.1.0
  * New features include: parallel PLUQ
  * computation of rank profiles and rank profile matrices
  * echelon and reduced echelon forms form both LUdivine and PLUQ
  * getters to the forms and the transformation matrices
  * igemm routine for BLAS like gemm on 64-bit ints
  * support of Modular<int64_t> and ModularBalanced<int64_t> using
  igemm, to support fields of bitsize between 25 and 31
  * support of Modular<rint<K> > for Z/pZ with p of size > 32 bit
  (based on Givaro's RecInt multiprecision integers)
  * support of RNS based gaussian elimination on multiprecision fields
  * Paladin: DSL for parallel programming adressing OMP, TBB and Kaapi
* Mon Dec 29 2014 jengelh@inai.de
- Remove unneeded xz BuildRequire
* Sat Nov  1 2014 avvissu@yandex.ru
- Fix build error on 32bit architecture:
  * add atlas macro
- Do not compile in DATE and TIME:
  * HTML_TIMESTAMP tag set to NO
* Sun Aug 10 2014 jengelh@inai.de
- Update to new upstream release 2.0.0
  * New features: new pluq 2x2 recursive algorithm; leftlooking;
  parallel OMP and KAAPI fgemm, ftrmm, ftrsm;
  fadd, fsub, finit, fscal, etc.; vectorisation using AVX(2);
  in place schedules; new Echelon code; spmv kernels
* Mon May 20 2013 jengelh@inai.de
- Initial package (version 1.6.0) for build.opensuse.org
